@@ -107,8 +107,7 @@ class Teacher(cfg.ConfigUtils):
 
 You really should restart the program now.""")
             return
-        if filter(lambda q: 'music' in q and q['music'].m_musictype == 'cmdline',
-                  self.m_P.m_questions):
+        if [q for q in self.m_P.m_questions if isinstance(q['music'], lessonfile.Cmdline)]:
             run = gu.dialog_yesno(_("The lessonfile contain potentially dangerous code because it run external programs. Run anyway?"))
             if not run:
                 self.m_P = None
@@ -185,14 +184,17 @@ class MelodicIntervalTeacher(Teacher):
                     off = 1000
                     best = None
                     for interval in self.get_list('ask_for_intervals_%i'%x):
-                        if t + interval > high:
-                            if t + interval - high < off:
-                                off = t + interval - high
-                                best = interval
-                        if t + interval < low:
-                            if low - (t + interval) < off:
-                                off = low - (t + interval)
-                                best = interval
+                        try:
+                            if t + interval > high:
+                                if t + interval - high < off:
+                                    off = t + interval - high
+                                    best = interval
+                            if t + interval < low:
+                                if low - (t + interval) < off:
+                                    off = low - (t + interval)
+                                    best = interval
+                        except ValueError:
+                            return self.ERR_CONFIGURE
                     i = best
                 self.m_question.append(i)
                 t = t + i
@@ -296,6 +298,7 @@ class RhythmAddOnClass:
         """
         rhythm is a string. Example: 'c4 c8 c8 c4'
         """
+        # FIXME can we use lessonfile.Rhythm insted of this?
         score = mpd.parser.parse_to_score_object(rhythm)
         track = score.get_midi_events_as_percussion(cfg.get_int('config/preferred_instrument_velocity'))[0]
         track.prepend_bpm(self.m_P.header.bpm)
