@@ -436,3 +436,96 @@ It is also possible that the OS sound setup is incorrect.
                     del self.m_abort_export
                     return
         reportlib.HtmlReport(report, os.path.join(export_dir, "toc.html"))
+    def sheet_gen_questions(self, count, sdict):
+        """
+        count -- how many questions should we generate. We use this value
+                 and not sdict['count'] because sometimes the app has some
+                 questions, and just need a few more.
+        """
+        module = self.lessonfile_manager.get(sdict['lesson_id'], 'module')
+        if module not in self.m_teachers:
+            self.create_teacher(module)
+        p = self.m_teachers[module].lessonfileclass(
+            self.lessonfile_manager.get(sdict['lesson_id'], 'filename'))
+        if module == 'idbyname':
+            for x in self._sheet_gen_question_idbyname(p, count, sdict):
+                yield x
+        else:
+            assert module in ('harmonicinterval', 'melodicinterval')
+            for x in self._sheet_gen_question_interval(module, p, count, sdict):
+                yield x
+    def _sheet_gen_question_idbyname(self, p, count, sdict):
+        """
+        yield count dicts, where each dict contain the data needed to
+        print both the teachers and the students question.
+        """
+        counts = {}.fromkeys(range(len(p.m_questions)), 0)
+        for x in range(count):
+            while 1:
+                p.select_random_question()
+                if counts[p._idx] >= 1.0 * sdict['count'] / len(p.m_questions):
+                    continue
+                counts[p._idx] += 1
+                break
+            ret = {'question': {}, 'answer': {}}
+            if sdict['qtype'] == 0:
+                ret['question']['name'] = "...."
+                ret['answer']['name'] = p.get_question()['name']
+                ret['question']['music'] = p.get_lilypond_code()
+                ret['answer']['music'] = p.get_lilypond_code()
+                yield ret
+            else:
+                assert sdict['qtype'] == 1
+                ret['question']['name'] = p.get_question()['name']
+                ret['answer']['name'] = p.get_question()['name']
+                ret['answer']['music'] = p.get_lilypond_code()
+                ret['question']['music'] = p.get_lilypond_code_first_note()
+                yield ret
+    def _sheet_gen_question_interval(self, module, p, count, sdict):
+        # FIXME in the idbyname we count how many times each question
+        # has been selected, so get an even selection. We don't do it
+        # here at the moment, because we need to descide what we really want.
+        teacher = self.m_teachers[module]
+        teacher.set_lessonfile(self.lessonfile_manager.get(sdict['lesson_id'],
+                                                          'filename'))
+        teacher.start_practise()
+        for x in range(count):
+            teacher.new_question("c'", "c''")
+            # quick hack to use this for both melodic and harmonic intervals
+            if module == 'melodicinterval':
+                teacher.m_interval = teacher.m_question[0]
+            teacher.q_status = const.QSTATUS_SOLVED
+            ret = {'question': {}, 'answer': {}}
+            if sdict['qtype'] == 0:
+                ret['question']['name'] = "...."
+                ret['answer']['name'] = const.int_interval[abs(teacher.m_interval)]
+                ret['question']['music'] = r"\score{" \
+                        r" { %s %s }" \
+                        r"\layout { "\
+                        r"  ragged-last = ##t " \
+                        r"  \context { \Staff " \
+                        r'\remove "Time_signature_engraver" } }' \
+                        r"}" % (
+                    teacher.m_tonika.get_octave_notename(),
+                    (teacher.m_tonika + mpd.Interval.new_from_int(teacher.m_interval)).get_octave_notename())
+                ret['answer']['music'] = ret['question']['music']
+                yield ret
+            else:
+                assert sdict['qtype'] == 1
+                ret['question']['name'] = const.int_interval[abs(teacher.m_interval)]
+                ret['answer']['name'] = const.int_interval[abs(teacher.m_interval)]
+                ret['question']['music'] = r"\score{ { %s s4 s4} "\
+                       r"\layout{ "\
+                       r"  ragged-last = ##t "\
+                       r"  \context { \Staff "\
+                       r'     \remove "Time_signature_engraver" } }'\
+                       r"}" % teacher.m_tonika.get_octave_notename()
+                ret['answer']['music'] = r"\score{ { %s %s } "\
+                       r"\layout{ "\
+                       r"  ragged-last = ##t "\
+                       r"  \context { \Staff "\
+                       r'     \remove "Time_signature_engraver" } }'\
+                       r"}" % (
+                    teacher.m_tonika.get_octave_notename(),
+                    (teacher.m_tonika + teacher.m_interval).get_octave_notename())
+                yield ret
