@@ -84,6 +84,15 @@ def setup(prefix, config_locale=None):
             if s:
                 s = locale.normalize(s)
                 os.environ['LANGUAGE'] = s
-    gettext.install('solfege', os.path.join(prefix, 'share', 'locale'), unicode=1)
-    __builtins__['_i'] = _i
+    import __builtin__
+    t = gettext.translation("solfege",
+                           os.path.join(prefix, 'share', 'locale'),
+                           fallback=True)
+    __builtin__.__dict__['_'] = t.ugettext
+    __builtin__.__dict__['_i'] = _i
+    __builtin__.__dict__['ngettext'] = t.ngettext
+    # plurals usage:
+    # i =  'some integer value'
+    # ngettext("%i car", "%i cars", i) % i
+
 
